Package: anytime
Type: Package
Title: Anything to 'POSIXct' or 'Date' Converter
Version: 0.3.13
Date: 2026-04-13
Authors@R: person("Dirk", "Eddelbuettel", role = c("aut", "cre"), email = "edd@debian.org",
                  comment = c(ORCID = "0000-0001-6419-907X"))
Description: Convert input in any one of character, integer, numeric, factor,
 or ordered type into 'POSIXct' (or 'Date') objects, using one of a number of
 predefined formats, and relying on Boost facilities for date and time parsing.
URL: https://github.com/eddelbuettel/anytime,
        https://dirk.eddelbuettel.com/code/anytime.html
BugReports: https://github.com/eddelbuettel/anytime/issues
License: GPL (>= 2)
Encoding: UTF-8
Depends: R (>= 3.2.0)
Imports: Rcpp (>= 1.1.1)
LinkingTo: Rcpp (>= 1.1.1), BH
Suggests: tinytest (>= 1.0.0), gettz
RoxygenNote: 6.0.1
VignetteBuilder: Rcpp
NeedsCompilation: yes
Packaged: 2026-04-14 12:03:22 UTC; edd
Author: Dirk Eddelbuettel [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6419-907X>)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-04-14 12:30:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 09:53:55 UTC; unix
Archs: anytime.so.dSYM
